import sqlite3
from typing import List, Any, Tuple

from gtagger.config import get_config

class Database:
    #def __init__(self, dbPath: str = None):
    # per ora cabliamo il dbpath, poi usiamo la DI
    def __init__(self, dbPath: str = "paperless.db"):
        self._dbpath = dbPath or get_config()
        try:
            self.conn = sqlite3.connect(self._dbpath)
            # NECESSARIO per ON DELETE CASCADE
            self.conn.execute('PRAGMA foreign_keys = ON;')
            self.conn.row_factory = sqlite3.Row  # per usare i nomi delle colonne
            self.cur = self.conn.cursor()
        except sqlite3.Error as e:
            raise RuntimeError(f"Errore durante la connessione al database {self._dbpath}: {e}")



    def execute(self, query: str, parameters: Tuple = ()) -> None:
        try:
            self.cur.execute(query, parameters)
            self.conn.commit()
        except sqlite3.Error as e:
            self.conn.rollback()
            raise RuntimeError(f"Errore durante l'esecuzione della query: {e}\nQuery: {query}")


    def fetchone(self, query: str, parameters: Tuple = ()) -> sqlite3.Row:
        try:
            self.cur.execute(query, parameters)
            return self.cur.fetchone()
        except sqlite3.Error as e:
            raise RuntimeError(f"Errore durante fetchone: {e}\nQuery: {query}")
    

    def fetchall(self, query: str, parameters: Tuple = ()) -> List[sqlite3.Row]:
        try:
            self.cur.execute(query, parameters)
            return self.cur.fetchall()
        except sqlite3.Error as e:
            raise RuntimeError(f"Errore durante fetchone: {e}\nQuery: {query}")

    def close(self):
        try:
            self.conn.close()
        except sqlite3.Error as e:
            raise RuntimeError(f"Errore durante la chiusura del database: {e}")
        


