from abc import ABC, abstractmethod
from typing import Optional,List
from pathlib import Path
import logging

log = logging.getLogger(__name__)

#from gtagger.convert.do_convert import ConversionResult
from gtagger.convert.conversion_result import ConversionResult
class PostConversionHandler(ABC):
    @abstractmethod
    def handle(self, file: Path, result: ConversionResult) -> Optional[bool]:
        """
        Se restituisce True → conversione gestita (es: creato .bl)
        E' un 'ping' del tipo: ho fatto qualcosa. Un segnale che in 
        futuro potrebbe essere gestito.
        """

class AiBlacklist(PostConversionHandler):
    def __init__(self, keywords: List[str]):
        self._keywords = keywords

    def handle(self, file: Path, result: ConversionResult) -> Optional[bool]:
        """
        Blacklist del documento in relazione al contenuto.
        Salva nel file '.bl' le corrispondenze trovate
        """
        if not result.success or not result.content:
            return False
        
        lowered_text = result.content.lower()

        matching_keywords = [kw for kw in self._keywords if kw in lowered_text]

        if matching_keywords:
            bl_file = file.with_suffix(".bl")
            try:
                with bl_file.open('w', encoding='utf-8') as f:
                    f.write('\n'.join(matching_keywords) + '\n')

                log.info(f"Creato sentinella .bl per {file.name} (match: {', '.join(matching_keywords)})")
                return True
            except IOError as e:
                log.error(f"Errore nella scrittura del file {bl_file}: {e}")
                return False

        return False
        